@@ -2,8 +2,7 @@ import logging
 
 import numpy as np
 import pandas as pd
-
-from scattertext import ScatterChart
+from scattertext.ScatterChart import ScatterChart
 from scattertext.Scalers import percentile_alphabetical
 from scattertext.DocsAndLabelsFromCorpus import DocsAndLabelsFromCorpus, DocsAndLabelsFromCorpusSample
 
@@ -168,8 +167,10 @@ class ScatterChartExplorer(ScatterChart):
             docs_getter = DocsAndLabelsFromCorpusSample(self.term_doc_matrix,
                                                         max_docs_per_category,
                                                         alternative_text_field=alternative_text_field)
-        if self.scatterchartdata.use_non_text_features:
+        if self.scatterchartdata.use_non_text_features or self.scatterchartdata.add_extra_features:
             docs_getter = docs_getter.use_non_text_features()
+            if self.scatterchartdata.add_extra_features:
+                docs_getter = docs_getter.use_terms_for_extra_features()
         return docs_getter
 
     def _get_docs_structure(self, docs_getter, metadata):
@@ -179,11 +180,18 @@ class ScatterChartExplorer(ScatterChart):
             return docs_getter.get_labels_and_texts()
 
     def _add_term_freq_to_json_df(self, json_df, term_freq_df, category):
-        ScatterChart._add_term_freq_to_json_df(self, json_df, term_freq_df, category)
-        json_df['cat'] = term_freq_df[category + ' freq'].astype(int)
-        json_df['ncat'] = term_freq_df['not cat freq'].astype(int)
+        json_df = ScatterChart._add_term_freq_to_json_df(self, json_df, term_freq_df, category).assign(
+            cat=term_freq_df[str(category) + ' freq'].astype(int),
+            ncat=term_freq_df['not cat freq'].astype(int)
+        )
+        # json_df.loc[:,'cat'] = term_freq_df[category + ' freq'].astype(int)
+        # json_df.loc[:,'ncat'] = term_freq_df['not cat freq'].astype(int)
         if self._term_metadata is not None:
-            json_df['etc'] = term_freq_df['term'].apply(lambda term: self._term_metadata.get(term, {}))
+            json_df = json_df.assign(
+                etc=term_freq_df['term'].apply(lambda term: self._term_metadata.get(term, {}))
+            )
+
+        return json_df
 
     def inject_term_metadata(self, metadata):
         '''
