@@ -1,10 +1,10 @@
 import warnings
 from copy import copy
+from typing import Union, List, Callable
 
 import numpy as np
 import pandas as pd
 import scipy
-from pandas.core.common import SettingWithCopyWarning
 from scipy.sparse import csr_matrix
 from scipy.stats import hmean, fisher_exact, rankdata, norm
 from sklearn.feature_extraction.text import TfidfTransformer
@@ -18,8 +18,6 @@ from scattertext.TermDocMatrixWithoutCategories import TermDocMatrixWithoutCateg
 from scattertext.indexstore import IndexStore, IndexStoreFromList
 from scattertext.termscoring.CornerScore import CornerScore
 
-warnings.simplefilter(action="ignore", category=SettingWithCopyWarning)
-
 from scattertext.termscoring.ScaledFScore import InvalidScalerException, ScaledFScore
 
 
@@ -80,6 +78,11 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
             d[category + ' freq'] = self._X[self._y == i].sum(axis=0).A1
         return pd.DataFrame(d).set_index('term')
 
+    def get_freq_df(self, use_metadata=False, label_append=' freq'):
+        if use_metadata:
+            return self.get_metadata_freq_df(label_append)
+        return self.get_term_freq_df(label_append)
+
     def get_term_freq_df(self, label_append=' freq'):
         '''
         Parameters
@@ -113,16 +116,21 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
             freq_mat[:, cat_i] = self._X[self._y == cat_i, :].sum(axis=0)
         return freq_mat
 
-    def get_term_count_mat(self):
+    def get_term_count_mat(self, non_text: bool = False):
         '''
+        Parameters
+        -------
+        non_text : bool = False
+
         Returns
         -------
         np.array with columns as categories and rows as terms
         '''
-        freq_mat = np.zeros(shape=(self.get_num_terms(), self.get_num_categories()),
-                            dtype=self.get_term_doc_mat().dtype)
+        freq_mat = np.zeros(shape=(self.get_num_terms(non_text=non_text), self.get_num_categories()),
+                            dtype=self.get_term_doc_mat(non_text=non_text).dtype)
+        Xall = self.get_term_doc_mat(non_text=non_text)
         for cat_i in range(self.get_num_categories()):
-            X = (self._X[self._y == cat_i, :] > 0).astype(int)
+            X = (Xall[self._y == cat_i, :] > 0).astype(int)
             freq_mat[:, cat_i] = X.sum(axis=0)
         return freq_mat
 
@@ -200,8 +208,12 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
         '''
         freq_mat = np.zeros(shape=(self.get_num_metadata(), self.get_num_categories()),
                             dtype=self.get_metadata_doc_mat().dtype)
+        mX = self._mX
+        if any(np.isnan(mX.data)):
+            mX = mX.copy()
+            mX.data = np.nan_to_num(mX.data, copy=False)
         for cat_i in range(self.get_num_categories()):
-            freq_mat[:, cat_i] = self._mX[self._y == cat_i, :].sum(axis=0)
+            freq_mat[:, cat_i] = mX[self._y == cat_i, :].sum(axis=0)
         return pd.DataFrame(freq_mat,
                             index=pd.Series(self.get_metadata(), name='term'),
                             columns=[str(c) + label_append for c in self.get_categories()])
@@ -256,7 +268,7 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
 
     def remove_categories(self, categories, ignore_absences=False):
         '''
-        Non destructive category removal.
+        Non-destructive category removal.
 
         Parameters
         ----------
@@ -735,17 +747,20 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
         '''
         return self._category_idx_store
 
-    def recategorize(self, new_categories):
+    def recategorize(self, new_categories: Union[List, Callable[['TermDocMatrix'], List]]):
         '''
         Parameters
         ----------
-        new_categories : array like
+        new_categories : array like or function which takes TermDocMatric and returns something list like
         String names of new categories. Length should be equal to number of documents
 
         Returns
         -------
         TermDocMatrix
         '''
+        if callable(new_categories):
+            new_categories = new_categories(self)
+
         assert len(new_categories) == self.get_num_docs()
 
         new_category_idx_store = IndexStoreFromList.build(set(new_categories))
@@ -778,7 +793,7 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
             new_y_mask=self._y == self._y
         )
 
-    def use_doc_labeled_terms_as_metadata(self, doc_labels, separator='_', replace_metadata = True):
+    def use_doc_labeled_terms_as_metadata(self, doc_labels, separator='_', replace_metadata=True):
         '''
         Makes the metadata of a new TermDocMatrix a copy of the term-document matrix, except each term is prefixed
         by its document's label followed by the separator.
@@ -799,7 +814,7 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
         ordered_doc_labels = list(sorted(set(doc_labels)))
         X = self._X
         if replace_metadata:
-            #X = self._mX
+            # X = self._mX
             X = self._X
 
         for doc_label in ordered_doc_labels:
@@ -853,10 +868,7 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
 
         :return: TermDocMatrix
         '''
-        new_metadata_factory = CSRMatrixFactory()
-        for i, category_idx in enumerate(self.get_category_ids()):
-            new_metadata_factory[i, category_idx] = 1
-        new_metadata = new_metadata_factory.get_csr_matrix()
+        new_metadata = self._categories_to_metadata_factory()
         new_tdm = self._make_new_term_doc_matrix(self._X,
                                                  new_metadata,
                                                  self._y,
@@ -873,18 +885,24 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
 
         :return: TermDocMatrix
         '''
+        new_metadata = self._categories_to_metadata_factory()
+        new_tdm = self._make_new_term_doc_matrix(
+            new_X=self._mX,
+            new_mX=new_metadata,
+            new_y=self._y,
+            new_term_idx_store=self._metadata_idx_store,
+            new_category_idx_store=self._category_idx_store,
+            new_metadata_idx_store=copy(self._category_idx_store),
+            new_y_mask=self._y == self._y,
+        )
+        return new_tdm
+
+    def _categories_to_metadata_factory(self):
         new_metadata_factory = CSRMatrixFactory()
         for i, category_idx in enumerate(self.get_category_ids()):
             new_metadata_factory[i, category_idx] = 1
         new_metadata = new_metadata_factory.get_csr_matrix()
-        new_tdm = self._make_new_term_doc_matrix(self._mX,
-                                                 new_metadata,
-                                                 self._y,
-                                                 self._metadata_idx_store,
-                                                 self._category_idx_store,
-                                                 copy(self._category_idx_store),
-                                                 self._y == self._y)
-        return new_tdm
+        return new_metadata
 
     def copy_terms_to_metadata(self):
         '''
@@ -905,3 +923,8 @@ class TermDocMatrix(TermDocMatrixWithoutCategories):
         :return: int
         '''
         return len(self.get_categories())
+
+    def remove_terms_used_in_less_than_num_categories(self, threshold, use_metadata=False):
+        term_mask = (self.get_freq_df(use_metadata=use_metadata).values > 0).sum(axis=1) < threshold
+        term_indices_to_remove = np.where(term_mask)[0]
+        return self.remove_terms_by_indices(term_indices_to_remove, use_metadata)
