@@ -2,6 +2,7 @@ import string
 from collections import Counter
 
 import numpy as np
+import pandas as pd
 
 from scattertext.CSRMatrixTools import CSRMatrixFactory
 from scattertext.TermDocMatrix import TermDocMatrix
@@ -18,8 +19,7 @@ class TermDocMatrixFactory(object):
                  category_text_iter=None,
                  clean_function=lambda x: x,
                  nlp=None,
-                 feats_from_spacy_doc=None
-                 ):
+                 feats_from_spacy_doc=None):
         """
         Class for easy construction of a term document matrix.
        This class let's you define an iterator for each document (text_iter),
@@ -125,7 +125,7 @@ class TermDocMatrixFactory(object):
         nlp = self.get_nlp()
 
         category_document_iter = (
-            (category, self._clean_function(raw_text))
+            (str(category), self._clean_function(raw_text))
             for category, raw_text
             in self._category_text_iter
         )
@@ -242,10 +242,12 @@ class TermDocMatrixFactory(object):
                                    term_idx_store,
                                    metadata_idx_store,
                                    y):
-        self._register_doc(X_factory, mX_factory, document_index, parsed_text, term_idx_store, metadata_idx_store)
+        self._register_doc(X_factory, mX_factory, document_index,
+                           parsed_text, term_idx_store, metadata_idx_store)
         self._register_category(category, category_idx_store, y)
 
-    def _register_doc(self, X_factory, mX_factory, document_index, parsed_text, term_idx_store, metadata_idx_store):
+    def _register_doc(self, X_factory, mX_factory, document_index,
+                      parsed_text, term_idx_store, metadata_idx_store):
         for term, count in self._feats_from_spacy_doc.get_feats(parsed_text).items():
             term_idx = term_idx_store.getidx(term)
             X_factory[document_index, term_idx] = count
