@@ -1,8 +1,10 @@
 import collections
 import re
+from typing import List
 
 import numpy as np
 import pandas as pd
+from scipy.sparse import csr_matrix
 
 from scattertext.CSRMatrixTools import delete_columns, CSRMatrixFactory
 from scattertext.FeatureOuput import FeatureLister
@@ -73,12 +75,14 @@ class TermDocMatrixWithoutCategories(object):
         '''
         return compactor.compact(self, non_text)
 
-    def get_num_terms(self):
+    def get_num_terms(self, non_text: bool = False):
         '''
         Returns
         -------
         The number of terms registered in the term doc matrix
         '''
+        if non_text:
+            return self.get_num_metadata()
         return len(self._term_idx_store)
 
     def get_num_docs(self):
@@ -113,13 +117,21 @@ class TermDocMatrixWithoutCategories(object):
         elif (type(background) == pd.DataFrame
               and set(background.columns) == set(['word', 'background'])):
             self._background_corpus = background
+        elif type(background) == pd.Series:
+            self._background_corpus = background
         else:
             raise Exception('The argument named background must be a subclass of TermDocMatrix or a ' \
                             + 'DataFrame with columns "word" and "background", where "word" ' \
                             + 'is the term text, and "background" is its frequency.')
 
+        return self
+
     def get_background_corpus(self):
         if self._background_corpus is not None:
+            if type(self._background_corpus) == pd.DataFrame:
+                return self._background_corpus['background']
+            elif type(self._background_corpus) == pd.Series:
+                return self._background_corpus
             return self._background_corpus
         return DefaultBackgroundFrequencies.get_background_frequency_df(self._unigram_frequency_path)
 
@@ -139,10 +151,15 @@ class TermDocMatrixWithoutCategories(object):
         ...
         '''
         background_df = self._get_background_unigram_frequencies()
+        if type(background_df) == pd.DataFrame:
+            background_df = background_df['background']
         corpus_freq_df = self.get_term_count_df()
         corpus_unigram_freq = self._get_corpus_unigram_freq(corpus_freq_df)
-        df = corpus_unigram_freq.join(background_df, how='outer').fillna(0)
-        return df
+
+        return pd.DataFrame({
+            'background': background_df,
+            'corpus': corpus_unigram_freq['corpus'],
+        }).fillna(0)
 
     def get_term_count_df(self):
         return pd.DataFrame({'corpus': self._X.sum(axis=0).A1, 'term': self.get_terms()}).set_index('term')
@@ -159,22 +176,24 @@ class TermDocMatrixWithoutCategories(object):
             return self.get_background_corpus()
         return DefaultBackgroundFrequencies.get_background_frequency_df(self._unigram_frequency_path)
 
-    def list_extra_features(self):
+    def list_extra_features(self, use_metadata=True):
         '''
         Returns
         -------
         List of dicts.  One dict for each document, keys are metadata, values are counts
         '''
-        return FeatureLister(self._mX,
-                             self._metadata_idx_store,
+        return FeatureLister(self._get_relevant_X(use_metadata),
+                             self._get_relevant_idx_store(use_metadata),
                              self.get_num_docs()).output()
 
-    def get_terms(self):
+    def get_terms(self, use_metadata=False):
         '''
         Returns
         -------
         np.array of unique terms
         '''
+        if use_metadata:
+            return self.get_metadata()
         return self._term_idx_store._i2val
 
     def get_metadata(self):
@@ -199,7 +218,7 @@ class TermDocMatrixWithoutCategories(object):
         new_X = delete_columns(self._get_relevant_X(non_text), idx_to_delete_list)
         return new_X, new_term_idx_store
 
-    def _get_relevant_X(self, non_text):
+    def _get_relevant_X(self, non_text: bool):
         return self._mX if non_text else self._X
 
     def _get_relevant_idx_store(self, non_text):
@@ -227,7 +246,7 @@ class TermDocMatrixWithoutCategories(object):
         :param non_text: bool, use metadata?
         :return: Corpus
         '''
-        tdm = (self.get_metadata_doc_mat() > 0) if non_text else (self.get_term_doc_mat() > 0)
+        tdm = self.get_term_doc_mat(non_text=non_text) > 0
         tdmpct = (tdm.sum(axis=0) / tdm.shape[0]).A1
         mask = (tdmpct >= min_document_pct) & (tdmpct <= max_document_pct)
         return self.remove_terms(np.array(self.get_terms())[mask])
@@ -246,7 +265,7 @@ class TermDocMatrixWithoutCategories(object):
         return self.remove_terms(terms_to_remove)
 
     def remove_terms(self, terms, ignore_absences=False, non_text=False):
-        '''Non destructive term removal.
+        '''Non-destructive term removal.
 
         Parameters
         ----------
@@ -366,10 +385,9 @@ class TermDocMatrixWithoutCategories(object):
     def _get_non_unigrams(self):
         return [term for term
                 in self._term_idx_store._i2val
-                if ' ' in term or (self._strict_unigram_definition and "'" in term)
-                ]
+                if ' ' in term or (self._strict_unigram_definition and "'" in term)]
 
-    def get_stoplisted_unigram_corpus(self, stoplist=None):
+    def get_stoplisted_unigram_corpus(self, stoplist=None, non_text: bool = False):
         '''
         Parameters
         -------
@@ -383,10 +401,24 @@ class TermDocMatrixWithoutCategories(object):
             stoplist = self.get_default_stoplist()
         else:
             stoplist = [w.lower() for w in stoplist]
-        return self._remove_terms_from_list(stoplist)
+        return self._remove_terms_from_list_and_all_non_unigrams(stoplist, non_text=non_text)
 
-    def get_stoplisted_unigram_corpus_and_custom(self,
-                                                 custom_stoplist):
+    def get_stoplisted_corpus(self, stoplist=None, non_text: bool = False):
+        '''
+        Parameters
+        -------
+        stoplist : list, optional
+        non_text : bool
+
+        Returns
+        -------
+        A new TermDocumentMatrix consisting of only unigrams in the current TermDocumentMatrix.
+        '''
+        if stoplist is None:
+            stoplist = self.get_default_stoplist()
+        return self.remove_terms([w.lower() for w in stoplist], ignore_absences=True, non_text=non_text)
+
+    def get_stoplisted_unigram_corpus_and_custom(self, custom_stoplist, non_text: bool = False):
         '''
         Parameters
         -------
@@ -398,24 +430,28 @@ class TermDocMatrixWithoutCategories(object):
         '''
         if type(custom_stoplist) == str:
             custom_stoplist = [custom_stoplist]
-        return self._remove_terms_from_list(set(self.get_default_stoplist())
-                                            | set(w.lower() for w in custom_stoplist))
+        return self._remove_terms_from_list_and_all_non_unigrams(
+            set(self.get_default_stoplist())
+            | set(w.lower() for w in custom_stoplist),
+            non_text=non_text
+        )
 
-    def filter_out(self, filter_func):
+    def filter_out(self, filter_func, non_text=False):
         '''
 
         :param filter_func: function which takes a string and returns true or false
         :return: A new TermDocumentMatrix consisting of only unigrams in the current TermDocumentMatrix.
         '''
-        return self.remove_terms([x for x in self.get_terms() if filter_func(x)])
+        return self.remove_terms([x for x in self.get_terms(use_metadata=non_text) if filter_func(x)],
+                                 non_text=non_text)
 
-    def _remove_terms_from_list(self, stoplist):
+    def _remove_terms_from_list_and_all_non_unigrams(self, stoplist, non_text=False):
         terms_to_ignore = [term for term
-                           in self._term_idx_store._i2val
+                           in (self._metadata_idx_store._i2val if non_text else self._term_idx_store._i2val)
                            if ' ' in term or (self._strict_unigram_definition
                                               and ("'" in term or '’' in term))
                            or term in stoplist]
-        return self.remove_terms(terms_to_ignore)
+        return self.remove_terms(terms_to_ignore, non_text=non_text)
 
     def metadata_in_use(self):
         '''
@@ -486,7 +522,7 @@ class TermDocMatrixWithoutCategories(object):
         )
         return df.sort_values(by='Scaled f-score', ascending=False)
 
-    def get_term_doc_mat(self):
+    def get_term_doc_mat(self, non_text: bool = False) -> csr_matrix:
         '''
         Returns sparse matrix representation of term-doc-matrix
 
@@ -494,9 +530,14 @@ class TermDocMatrixWithoutCategories(object):
         -------
         scipy.sparse.csr_matrix
         '''
+        if non_text:
+            return self.get_metadata_doc_mat()
         return self._X
 
-    def get_term_doc_mat_coo(self):
+    def get_term_freqs(self, non_text: bool = False) -> np.array:
+        return self.get_term_doc_mat(non_text=non_text).sum(axis=0).A1
+
+    def get_term_doc_mat_coo(self, non_text: bool = False):
         '''
         Returns sparse matrix representation of term-doc-matrix
 
@@ -504,7 +545,7 @@ class TermDocMatrixWithoutCategories(object):
         -------
         scipy.sparse.coo_matrix
         '''
-        return self._X.astype(np.double).tocoo()
+        return self.get_term_doc_mat(non_text=non_text).astype(np.double).tocoo()
 
     def get_metadata_doc_mat(self):
         '''
@@ -564,6 +605,23 @@ class TermDocMatrixWithoutCategories(object):
             metafact[i, i] = doc_name_idx
         return self.add_metadata(metafact.get_csr_matrix(), metaidxstore)
 
+    def get_term_index(self, term: str) -> int:
+        return self._term_idx_store.getidxstrict(term)
+
+    def get_term_from_index(self, index: int) -> str:
+        return self._term_idx_store.getval(index)
+
+    def get_term_index_store(self, non_text=False):
+        return self._metadata_idx_store if non_text else self._term_idx_store
+
+    def get_document_ids_with_terms(self, terms: List[str], use_non_text_features: bool = False) -> np.array:
+        return np.where(
+            self._get_relevant_X(use_non_text_features)[
+            :,
+            [self._term_idx_store.getidx(x) for x in terms if x in self._term_idx_store]
+            ].sum(axis=1).A1 > 0
+        )[0]
+
     def add_metadata(self, metadata_matrix, meta_index_store):
         '''
         Returns a new corpus with a the metadata matrix and index store integrated.
