@@ -1,5 +1,6 @@
 from collections import Counter
 from itertools import chain
+import pandas as pd
 
 
 class FeatsFromSpacyDoc(object):
@@ -37,6 +38,9 @@ class FeatsFromSpacyDoc(object):
 	def get_doc_metadata(self, doc):
 		return Counter()
 
+	def get_row_metadata(self, doc, row: pd.Series):
+		return Counter()
+
 	def ignore_censored_types(self):
 		self._ignore_censored_types = True
 		return self
