@@ -3,4 +3,7 @@ class FeatAndOffsetGetter(object):
         return None
 
     def get_metadata_offsets(self, doc):
-        return None
\ No newline at end of file
+        return None
+
+    def get_metadata_row_offsets(self, doc, row):
+        return []
\ No newline at end of file
