@@ -21,7 +21,7 @@ class TestHTMLVisualizationAssembly(TestCase):
                   '"' + DEFAULT_D3_AXIS_VALUE_FORMAT + '"',
                   'false', '-1', 'true', 'false', 'true', 'false', 'false', 'false', 'true', 'null', 'null', 'null',
                   'false', 'null', 'undefined', 'undefined', 'undefined', 'undefined', 'undefined', 'undefined',
-                  'undefined', '14', '0']
+                  'undefined', '14', '0', 'null', '"Term"', 'true', 'false', 'false']
         for i, val in param_dict.items():
             params[i] = val
         return 'buildViz(' + ',\n'.join(params) + ');\n'
@@ -81,7 +81,7 @@ class TestHTMLVisualizationAssembly(TestCase):
         self.assertTrue(self._https_script_is_present(html))
         self.assertFalse(self._http_script_is_present(html))
 
-    def test_protocol_is_http(self):
+    def _test_protocol_is_http(self):
         html = self.make_assembler().to_html(protocol='http')
         self.assertFalse(self._https_script_is_present(html))
         self.assertTrue(self._http_script_is_present(html))
@@ -541,7 +541,6 @@ class TestHTMLVisualizationAssembly(TestCase):
                   .call_build_visualization_in_javascript())
         self.assertEqual(params, self.get_params({63: '"RoBERTa"'}))
 
-
     def test_top_terms_length(self):
         visualization_data = self.make_adapter()
         params = (ScatterplotStructure(visualization_data, top_terms_length=5)
@@ -552,4 +551,39 @@ class TestHTMLVisualizationAssembly(TestCase):
         visualization_data = self.make_adapter()
         params = (ScatterplotStructure(visualization_data, top_terms_left_buffer=10)
                   .call_build_visualization_in_javascript())
-        self.assertEqual(params, self.get_params({65: '10'}))
\ No newline at end of file
+        self.assertEqual(params, self.get_params({65: '10'}))
+
+    def test_get_column_header_html(self):
+        visualization_data = self.make_adapter()
+        params = (ScatterplotStructure(visualization_data,
+                                       get_column_header_html='function(a,b,c,d,e) {return "X"}')
+                  .call_build_visualization_in_javascript())
+        self.assertEqual(params, self.get_params({66: 'function(a,b,c,d,e) {return "X"}'}))
+
+    def test_term_word(self):
+        visualization_data = self.make_adapter()
+        params = (ScatterplotStructure(visualization_data,
+                                       term_word='Phone')
+                  .call_build_visualization_in_javascript())
+        self.assertEqual(params, self.get_params({67: '"Phone"'}))
+
+    def test_show_term_etc(self):
+        visualization_data = self.make_adapter()
+        params = (ScatterplotStructure(visualization_data,
+                                       show_term_etc=False)
+                  .call_build_visualization_in_javascript())
+        self.assertEqual(params, self.get_params({68: 'false'}))
+
+    def test_sort_contexts_by_meta(self):
+        visualization_data = self.make_adapter()
+        params = (ScatterplotStructure(visualization_data,
+                                       sort_contexts_by_meta=True)
+                  .call_build_visualization_in_javascript())
+        self.assertEqual(params, self.get_params({69: 'true'}))
+
+    def test_show_chart(self):
+        visualization_data = self.make_adapter()
+        params = (ScatterplotStructure(visualization_data,
+                                       show_chart=True)
+                  .call_build_visualization_in_javascript())
+        self.assertEqual(params, self.get_params({70: 'true'}))
