@@ -76,7 +76,12 @@ class ScatterplotStructure(object):
             right_order_column=None,
             subword_encoding=None,
             top_terms_length=14,
-            top_terms_left_buffer=0
+            top_terms_left_buffer=0,
+            get_column_header_html=None,
+            term_word="Term",
+            show_term_etc=True,
+            sort_contexts_by_meta=False,
+            show_chart=False
     ):
         '''
 
@@ -232,6 +237,17 @@ class ScatterplotStructure(object):
             Number of top terms to show for left-hand side lists
         top_terms_lefft_buffer: int, default 0
             Number of pixels left to shift top terms list
+        get_column_header_html : str, default None
+            Javascript function to return html over each column. Matches header
+            (Column Name, occurrences per 25k, occs, # occs * 1000/num docs, term info)
+        term_word: str, default "Term"
+            Word for term in visualization
+        show_term_etc: bool, default True
+            Shows contents of etc structure after clicking on term
+        sort_contexts_by_meta : bool, default False
+            Sort contexts by meta instead of match strength
+        show_chart : bool, default False
+            Show line graph
         '''
         self._visualization_data = visualization_data
         self._width_in_pixels = width_in_pixels if width_in_pixels is not None else 1000
@@ -300,6 +316,11 @@ class ScatterplotStructure(object):
         self._subword_encoding = subword_encoding
         self._top_terms_length = top_terms_length
         self._top_terms_left_buffer = top_terms_left_buffer
+        self._get_column_header_html = get_column_header_html
+        self._term_word = term_word
+        self._show_term_etc = show_term_etc
+        self._sort_contexts_by_meta = sort_contexts_by_meta
+        self._show_chart = show_chart
 
     def call_build_visualization_in_javascript(self):
         def js_default_value(x, default='undefined'):
@@ -408,7 +429,12 @@ class ScatterplotStructure(object):
             js_default_string(self._right_order_column),
             js_default_string(self._subword_encoding),
             js_default_value(self._top_terms_length, '14'),
-            js_default_value(self._top_terms_left_buffer, '0')
+            js_default_value(self._top_terms_left_buffer, '0'),
+            js_default_value_to_null(self._get_column_header_html),
+            js_default_string(self._term_word),
+            js_bool(self._show_term_etc),
+            js_bool(self._sort_contexts_by_meta),
+            js_bool(self._show_chart)
         ]
         return 'buildViz(' + ',\n'.join(arguments) + ');\n'
 
